import axios from "axios";

export default {
  fetchCustomerData({ dispatch, commit }, data = {}) {
    let query;
    if (data.filterColumn == "all") {
      query = "q=" + data.searchInput;
    } else if (data.filterColumn) {
      query = data.filterColumn + "_like=" + data.searchInput;
    }
    commit("setLoading", true);
    axios
      .get(`http://localhost:3000/customers?${query}`)
      .then((response) => {
        commit("setCustomerList", response.data);

        dispatch("filterCustomer", { searchInput: "" });
        commit("setLoading", false);
      })
      .catch((e) => {
        console.log(e);
      });
  },

  toggleSingleExpand({ commit }) {
    commit("setSingleExpand");
  },

  closeDialog({ commit }) {
    commit("setDialog", false);
  },
  deleteCustomer({ dispatch, commit }, idList) {
    confirm("Are you sure you want to delete this item?") &&
      idList.forEach((id) => {
        commit("setLoading", true);
        axios
          .delete(`http://localhost:3000/customers/${id}`)
          .then(() => {
            dispatch("fetchCustomerData");
            commit("setLoading", false);
          })
          .catch((e) => {
            console.log(e);
          });
      });
  },
  deleteMultiCustomer({ dispatch }, items) {
    const itemList = [];
    items.forEach((item) => {
      itemList.push(item.id);
    });
    dispatch("deleteCustomer", itemList);
  },

  saveCustomer({ getters, dispatch, commit }) {
    const postConfig = {
      method: "post",
      url: `http://localhost:3000/customers/`,
      data: getters.editedItem,
    };

    const putConfig = {
      method: "put",
      url: `http://localhost:3000/customers/${getters.editedItem.id}`,
      data: getters.editedItem,
    };
    commit("setLoading", true);
    axios(!getters.editedItem.id ? postConfig : putConfig).then(() => {
      dispatch("fetchCustomerData");
      commit("setLoading", false);
    });
    dispatch("closeDialog");
  },

  editCustomer({ commit, getters }, item) {
    commit("setEditedIndex", getters.customerList.indexOf(item));
    commit("setEditedItem", Object.assign({}, item));
    commit("setDialog", true);
  },

  filterCustomer({ getters, commit }, data) {
    let x;
    if (!data.searchInput) {
      x = getters.customerList;
    } else {
      x = getters.customerList.filter((customer) => {
        if (customer[data.filterColumn]) {
          return customer[data.filterColumn]
            .toLowerCase()
            .includes(data.searchInput.toLowerCase());
        }
      });
    }
    commit("setfilteredCustomerList", x);
  },
};
