import axios from "axios";

export default {
  fetchProductData({ dispatch, commit }, data = {}) {
    let query;
    if (data.filterColumn == "all") {
      query = "q=" + data.searchInput;
    } else if (data.filterColumn) {
      query = data.filterColumn + "_like=" + data.searchInput;
    }
    commit("setLoading", true);
    axios
      .get(`http://localhost:3000/products?${query}`)
      .then((response) => {
        commit("setProductList", response.data);
        dispatch("filterProduct", { searchInput: "" });
        commit("setLoading", false);
      })
      .catch((e) => {
        console.log(e);
      });
  },

  toggleSingleExpand({ commit }) {
    commit("setSingleExpand");
  },

  closeDialog({ commit }) {
    commit("setDialog", false);
  },

  deleteProduct({ dispatch, commit }, idList) {
    confirm("Are you sure you want to delete this item?") &&
      idList.forEach((id) => {
        commit("setLoading", true);

        axios
          .delete(`http://localhost:3000/products/${id}`)
          .then(() => {
            dispatch("fetchProductData");
            commit("setLoading", false);
          })
          .catch((e) => {
            console.log(e);
          });
      });
    this.itemList = [];
  },

  deleteMultiProduct({ dispatch }, items) {
    const itemList = [];
    items.forEach((item) => {
      itemList.push(item.id);
    });
    dispatch("deleteProduct", itemList);
  },

  saveProduct({ getters, dispatch, commit }) {
    const postConfig = {
      method: "post",
      url: `http://localhost:3000/products/`,
      data: getters.editedItem,
    };

    const putConfig = {
      method: "put",
      url: `http://localhost:3000/products/${getters.editedItem.id}`,
      data: getters.editedItem,
    };
    commit("setLoading", true);

    axios(!getters.editedItem.id ? postConfig : putConfig).then(() => {
      dispatch("fetchProductData");
      commit("setLoading", false);
    });
    dispatch("closeDialog");
  },

  editProduct({ commit, getters }, item) {
    commit("setEditedIndex", getters.productList.indexOf(item));
    commit("setEditedItem", Object.assign({}, item));
    commit("setDialog", true);
  },

  filterProduct({ getters, commit }, data) {
    let x;
    if (!data.searchInput) {
      x = getters.productList;
    } else {
      x = getters.productList.filter((product) => {
        if (product[data.filterColumn]) {
          return product[data.filterColumn]
            .toLowerCase()
            .includes(data.searchInput.toLowerCase());
        }
      });
    }
    commit("setfilteredProductList", x);
  },
};
